@@ -1,5 +1,6 @@
 from .augmentations.background_noise import AddBackgroundNoise
 from .augmentations.colored_noise import AddColoredNoise
+from .augmentations.band_pass_filter import BandPassFilter
 from .augmentations.gain import Gain
 from .augmentations.high_pass_filter import HighPassFilter
 from .augmentations.impulse_response import ApplyImpulseResponse
@@ -8,8 +9,9 @@ from .augmentations.peak_normalization import PeakNormalization
 from .augmentations.polarity_inversion import PolarityInversion
 from .augmentations.shift import Shift
 from .augmentations.shuffle_channels import ShuffleChannels
+from .augmentations.pitch_shift import PitchShift
 from .core.composition import Compose
 from .utils.config import from_dict, from_yaml
 from .utils.convolution import convolve
 
-__version__ = "0.8.0"
+__version__ = "0.9.0"
